/**************************************************************** 
 * Description: 2021年CSP-S复赛，模拟算法，30分
 * Author: Alex Li
 * Date: 2024-08-04 18:04:32
 * LastEditTime: 2024-08-06 17:20:34
****************************************************************/
#include <iostream>
#include <vector>
#include <cstring>
#include <algorithm>
using namespace std;

// 定义航班结构体，包含起飞时间和降落时间
struct airTime{
    int b; // 航班开始时间
    int e; // 航班结束时间
} temp;

// 比较函数，用于按开始时间排序航班
bool compare(airTime a, airTime c){
    return a.b < c.b;
}

int main() {
    int n, dom, inte; // n 表示廊桥数量，dom 表示国内航班数量，inte 表示国际航班数量
    cin >> n >> dom >> inte; // 读取输入值
    
    vector<airTime> airTimeDom; // 存储国内航班信息
    vector<airTime> airTimeinte; // 存储国际航班信息
    
    // 读取所有国内航班信息
    for (int i = 0; i < dom; i++) {
        cin >> temp.b >> temp.e; // 读取航班的开始时间和结束时间
        airTimeDom.push_back(temp); // 添加到国内航班列表
    }
    
    // 按航班开始时间对国内航班排序
    sort(airTimeDom.begin(), airTimeDom.end(), compare);
    
    // 读取所有国际航班信息
    for (int i = 0; i < inte; i++) {
        cin >> temp.b >> temp.e; // 读取航班的开始时间和结束时间
        airTimeinte.push_back(temp); // 添加到国际航班列表
    }
    
    // 按航班开始时间对国际航班排序
    sort(airTimeinte.begin(), airTimeinte.end(), compare);
    
    int anss = 0; // 最终能停靠廊桥的最大航班数量
    
    // 遍历所有可能的廊桥分配方案
    for (int i = 0; i <= n; i++) {
        int ansd = 0; // 国内航班计数
        
        // 如果分配的廊桥数大于0
        if (i != 0) {
            int domline[i]; // 存储当前使用的廊桥分配情况
            bool sp = false; // 用于标记是否已分配完所有廊桥
            memset(domline, -1, sizeof(domline)); // 初始化廊桥分配数组为-1
            
            // 遍历所有国内航班
            for (int j = 0; j < dom; j++) {
                if (!sp) { // 如果还未分配完所有廊桥
                    for (int k = 0; k < i; k++) {
                        if (domline[k] == -1) { // 如果当前廊桥空闲
                            domline[k] = j; // 分配当前航班到该廊桥
                            ansd++; // 国内航班计数增加
                            if (ansd == i) { // 如果已分配完所有廊桥
                                sp = true; // 标记分配完成
                                break;
                            }
                            j++;
                        }
                    }
                } else {
                    for (int k = 0; k < i; k++) {
                        // 如果当前航班可以使用该廊桥
                        if (airTimeDom[j].b > airTimeDom[domline[k]].e) { 
                            domline[k] = j; // 更新廊桥分配
                            ansd++; // 国内航班计数增加
                            break;
                        }
                    }
                }
            }
        }
        
        int x = n - i; // 剩余廊桥数用于国际航班
        int ansi = 0; // 国际航班计数
        
        // 如果剩余廊桥数大于0
        if (x != 0) {
            int inteline[x]; // 存储当前使用的廊桥分配情况
            bool sp = false; // 用于标记是否已分配完所有廊桥
            memset(inteline, -1, sizeof(inteline)); // 初始化廊桥分配数组为-1
            
            // 遍历所有国际航班
            for (int j = 0; j < inte; j++) {
                if (!sp) { // 如果还未分配完所有廊桥
                    for (int k = 0; k < x; k++) {
                        if (inteline[k] == -1) { // 如果当前廊桥空闲
                            inteline[k] = j; // 分配当前航班到该廊桥
                            ansi++; // 国际航班计数增加
                            if (ansi == x) { // 如果已分配完所有廊桥
                                sp = true; // 标记分配完成
                                break;
                            }
                            j++;
                        }
                    }
                } else {
                    for (int k = 0; k < x; k++) {
                        // 如果当前航班可以使用该廊桥
                        if (airTimeinte[j].b > airTimeinte[inteline[k]].e) { 
                            inteline[k] = j; // 更新廊桥分配
                            ansi++; // 国际航班计数增加
                            break;
                        }
                    }
                }
            }
        }
        
        anss = max(anss, ansi + ansd); // 更新最大停靠航班数量
    }
    
    cout << anss; // 输出最大停靠航班数量
}

    
    